@@ -13,7 +13,7 @@ use Encode;
 
 has toUTF8 => sub { find_encoding('utf8') };
 
-our $VERSION = '1.0.13';
+our $VERSION = '1.0.14';
 
 has 'service';
 
@@ -217,28 +217,29 @@ sub renderJsonRpcError {
     for (ref $exception){
         /HASH/ && $exception->{message} && do {
             $error = {
-                origin => $exception->{origin} || 2, 
+                origin  => $exception->{origin} || 2,
                 message => $exception->{message}, 
-                code=>$exception->{code}
+                code    => $exception->{code}
             };
             last;
         };
         /.+/ && $exception->can('message') && $exception->can('code') && do {
             $error = {
-                origin => 2, 
+                origin  => 2,
                 message => $exception->message(), 
-                code=>$exception->code()
+                code    => $exception->code()
             };
             last;
         };
+        $self->log->error("Error while processing " . $self->service. "::" . $self->methodName . ": $exception");
         $error = {
-            origin => 2, 
-            message => "error while processing ".$self->service."::".$self->methodName.": $exception", 
-            code=> 9999
+            origin  => 2,
+            message => "Couldn't process request",
+            code    => 9999
         };
     }
-    $self->log->error("JsonRPC Error $error->{code}: $error->{message}");
-    $self->finalizeJsonRpcReply(encode_json({ id => $self->requestId, error => $error}));
+    $self->log->error("JsonRPC error sent to client: '$error->{code}: $error->{message}'");
+    $self->finalizeJsonRpcReply(encode_json({ id => $self->requestId, error => $error }));
 }
 
 sub finalizeJsonRpcReply {
